==> miaozhen-ui-1.0.33.tgz: package/src/index.js <==
import MzButton from './components/button/mz-button';/*按钮*/
import MzRadio from './components/radio/mz-radio';/*单选框*/
import MzRadioGroup from '@/components/radio/mz-radio-group'//单选框组
import MzRadioButton from '@/components/radio/mz-radio-button'//单选按钮
import MzBreadcrumb from './components/breadcrumb/mz-breadcrumb'/*面包屑导航*/
import MzBreadcrumbItem from './components/breadcrumb/mz-breadcrumb-item'/*面包屑导航其中一项*/
import MzMenu from './components/menu/mz-menu'/*导航*/
import MzSubmenu from './components/menu/mz-submenu'/*子导航*/
import MzMenuItem from './components/menu/mz-menu-item'/*导航条中的其中一项*/
import MzRow from './components/row/row'/*栅格布局行*/
import MzCol from './components/row/col'/*栅格布局栏*/
import MzCheckbox from './components/checkbox/mz-checkbox'/*复选框*/
import MzCheckboxGroup from './components/checkbox/mz-checkbox-group'//复选框组
import MzCheckboxButton from './components/checkbox/mz-checkbox-button'//复选按钮样式
import MzInput from './components/input/mz-input'/*输入框*/
import MzSelect from '@/components/select/mz-select'//下拉列表
import MzOption from '@/components/select/mz-option'//下拉列表选项
import MzOptionGroup from '@/components/select/mz-option-group'//下拉列表选项分组
import MzTag from '@/components/tag/mz-tag'//tag标签
import MzTable from '@/components/table/table'//表格
import MzTableColumn from '@/components/table/table-column'//表格中的一列
import MzIcon from '@/components/icon/mz-icon'//Icon图标
import MzPopover from '@/components/popover/main'//浮动标签
import MzPagination from '@/components/pagination/pagination'//分页
import MzDatePicker from '@/components/date-picker/picker/date-picker'//日期选择
import MzTimeSelect from '@/components/date-picker/picker/time-select'//时间选择
import MzTimePicker from '@/components/date-picker/picker/time-picker'//时间选择
import MzTooltip from '@/components/tooltip/main.js'//tooltip
import MzSwitch from '@/components/switch/mz-switch'//switch开关
import MzProgress from '@/components/progress/mz-progress'//进度条
import MzMessage from '@/components/message/main.js'
import MzMessageBox from '@/components/message-box/main.js'//alert,confirm,prompt
import MzUpload from '@/components/upload/index'//上传
import MzDropdown from '@/components/dropdown/mz-dropdown'//下拉菜单
import MzDropdownMenu from '@/components/dropdown/mz-dropdown-menu'//下拉菜单里的菜单
import MzDropdownItem from '@/components/dropdown/mz-dropdown-item'//下拉菜单一项
import MzTransfer from '@/components/transfer/main'//穿梭框
import MzAlert from '@/components/alert/mz-alert'//alert警告框
import Notification from '@/components/notification/main.js';//通知
import Loading from '@/components/loading/index.js'//loading加载
import locale from '@/locale';
var components = [
  MzButton,
  MzRadio,
  MzRadioGroup,
  MzRadioButton,
  MzBreadcrumb,
  MzBreadcrumbItem,
  MzMenu,
  MzSubmenu,
  MzMenuItem,
  MzRow,
  MzCol,
  MzCheckbox,
  MzCheckboxGroup,
  MzCheckboxButton,
  MzInput,
  MzSelect,
  MzOption,
  MzOptionGroup,
  MzTag,
  MzTable,
  MzTableColumn,
  MzIcon,
  MzPopover,
  MzPagination,
  MzDatePicker,
  MzTimeSelect,
  MzTimePicker,
  MzTooltip,
  MzSwitch,
  MzProgress,
  // MzMessage,
  // MzMessageBox,
  MzUpload,
  MzDropdown,
  MzDropdownMenu,
  MzDropdownItem,
  MzTransfer,
  MzAlert
];

const install = function(Vue, opts = {}) {
  locale.use(opts.locale);
  locale.i18n(opts.i18n);

  components.map(component => {
    Vue.component(component.name, component);
  });

  Vue.use(Loading.directive);

  const ELEMENT = {};
  ELEMENT.size = opts.size || '';

  Vue.prototype.$loading = Loading.service;
  //为了可直接使用this.$confirm(`确定移除 ${ file.name }？`)
  Vue.prototype.$msgbox = MzMessageBox;
  Vue.prototype.$alert = MzMessageBox.alert;
  Vue.prototype.$confirm = MzMessageBox.confirm;
  Vue.prototype.$prompt = MzMessageBox.prompt;
  Vue.prototype.$notify = Notification;
  Vue.prototype.$message = MzMessage;

  Vue.prototype.$ELEMENT = ELEMENT;
};

/* istanbul ignore if */
if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue);
};

export default {
  version: '1.0.33',
  locale: locale.use,
  i18n: locale.i18n,
  install,
  MzButton,
  MzRadio,
  MzRadioGroup,
  MzRadioButton,
  MzBreadcrumb,
  MzBreadcrumbItem,
  MzMenu,
  MzSubmenu,
  MzMenuItem,
  MzRow,
  MzCol,
  MzCheckbox,
  MzCheckboxGroup,
  MzCheckboxButton,
  MzInput,
  MzSelect,
  MzOption,
  MzOptionGroup,
  MzTag,
  MzTable,
  MzTableColumn,
  MzIcon,
  MzPopover,
  MzPagination,
  MzDatePicker,
  MzTimeSelect,
  MzTimePicker,
  MzTooltip,
  MzSwitch,
  MzProgress,
  MzMessage,
  MzMessageBox,
  MzUpload,
  MzDropdown,
  MzDropdownMenu,
  MzDropdownItem,
  MzTransfer,
  MzAlert,
  Notification,
  Loading
};

==> miaozhen-ui-1.0.34.tgz: package/src/index.js <==
import MzButton from './components/button/mz-button';/*按钮*/
import MzRadio from './components/radio/mz-radio';/*单选框*/
import MzRadioGroup from '@/components/radio/mz-radio-group'//单选框组
import MzRadioButton from '@/components/radio/mz-radio-button'//单选按钮
import MzBreadcrumb from './components/breadcrumb/mz-breadcrumb'/*面包屑导航*/
import MzBreadcrumbItem from './components/breadcrumb/mz-breadcrumb-item'/*面包屑导航其中一项*/
import MzMenu from './components/menu/mz-menu'/*导航*/
import MzSubmenu from './components/menu/mz-submenu'/*子导航*/
import MzMenuItem from './components/menu/mz-menu-item'/*导航条中的其中一项*/
import MzRow from './components/row/row'/*栅格布局行*/
import MzCol from './components/row/col'/*栅格布局栏*/
import MzCheckbox from './components/checkbox/mz-checkbox'/*复选框*/
import MzCheckboxGroup from './components/checkbox/mz-checkbox-group'//复选框组
import MzCheckboxButton from './components/checkbox/mz-checkbox-button'//复选按钮样式
import MzInput from './components/input/mz-input'/*输入框*/
import MzSelect from '@/components/select/mz-select'//下拉列表
import MzOption from '@/components/select/mz-option'//下拉列表选项
import MzOptionGroup from '@/components/select/mz-option-group'//下拉列表选项分组
import MzTag from '@/components/tag/mz-tag'//tag标签
import MzTable from '@/components/table/table'//表格
import MzTableColumn from '@/components/table/table-column'//表格中的一列
import MzIcon from '@/components/icon/mz-icon'//Icon图标
import MzPopover from '@/components/popover/main'//浮动标签
import MzPagination from '@/components/pagination/pagination'//分页
import MzDatePicker from '@/components/date-picker/picker/date-picker'//日期选择
import MzTimeSelect from '@/components/date-picker/picker/time-select'//时间选择
import MzTimePicker from '@/components/date-picker/picker/time-picker'//时间选择
import MzTooltip from '@/components/tooltip/main.js'//tooltip
import MzSwitch from '@/components/switch/mz-switch'//switch开关
import MzProgress from '@/components/progress/mz-progress'//进度条
import MzMessage from '@/components/message/main.js'
import MzMessageBox from '@/components/message-box/main.js'//alert,confirm,prompt
import MzUpload from '@/components/upload/index'//上传
import MzDropdown from '@/components/dropdown/mz-dropdown'//下拉菜单
import MzDropdownMenu from '@/components/dropdown/mz-dropdown-menu'//下拉菜单里的菜单
import MzDropdownItem from '@/components/dropdown/mz-dropdown-item'//下拉菜单一项
import MzTransfer from '@/components/transfer/main'//穿梭框
import MzAlert from '@/components/alert/mz-alert'//alert警告框
import Notification from '@/components/notification/main.js';//通知
import Loading from '@/components/loading/index.js'//loading加载
import locale from '@/locale';//国际化
import MzDialog from '@/components/dialog/mz-dialog'//dialog弹窗
import MzForm from '@/components/form/mz-form'//form表单
import MzFormItem from '@/components/form/mz-form-item'//form表单其中一项
var components = [
  MzButton,
  MzRadio,
  MzRadioGroup,
  MzRadioButton,
  MzBreadcrumb,
  MzBreadcrumbItem,
  MzMenu,
  MzSubmenu,
  MzMenuItem,
  MzRow,
  MzCol,
  MzCheckbox,
  MzCheckboxGroup,
  MzCheckboxButton,
  MzInput,
  MzSelect,
  MzOption,
  MzOptionGroup,
  MzTag,
  MzTable,
  MzTableColumn,
  MzIcon,
  MzPopover,
  MzPagination,
  MzDatePicker,
  MzTimeSelect,
  MzTimePicker,
  MzTooltip,
  MzSwitch,
  MzProgress,
  // MzMessage,
  // MzMessageBox,
  MzUpload,
  MzDropdown,
  MzDropdownMenu,
  MzDropdownItem,
  MzTransfer,
  MzAlert,
  MzDialog,
  MzForm,
  MzFormItem
];

const install = function(Vue, opts = {}) {
  locale.use(opts.locale);
  locale.i18n(opts.i18n);

  components.map(component => {
    Vue.component(component.name, component);
  });

  Vue.use(Loading.directive);

  const ELEMENT = {};
  ELEMENT.size = opts.size || '';

  Vue.prototype.$loading = Loading.service;
  //为了可直接使用this.$confirm(`确定移除 ${ file.name }？`)
  Vue.prototype.$msgbox = MzMessageBox;
  Vue.prototype.$alert = MzMessageBox.alert;
  Vue.prototype.$confirm = MzMessageBox.confirm;
  Vue.prototype.$prompt = MzMessageBox.prompt;
  Vue.prototype.$notify = Notification;
  Vue.prototype.$message = MzMessage;

  Vue.prototype.$ELEMENT = ELEMENT;
};

/* istanbul ignore if */
if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue);
};

export default {
  version: '1.0.34',
  locale: locale.use,
  i18n: locale.i18n,
  install,
  MzButton,
  MzRadio,
  MzRadioGroup,
  MzRadioButton,
  MzBreadcrumb,
  MzBreadcrumbItem,
  MzMenu,
  MzSubmenu,
  MzMenuItem,
  MzRow,
  MzCol,
  MzCheckbox,
  MzCheckboxGroup,
  MzCheckboxButton,
  MzInput,
  MzSelect,
  MzOption,
  MzOptionGroup,
  MzTag,
  MzTable,
  MzTableColumn,
  MzIcon,
  MzPopover,
  MzPagination,
  MzDatePicker,
  MzTimeSelect,
  MzTimePicker,
  MzTooltip,
  MzSwitch,
  MzProgress,
  MzMessage,
  MzMessageBox,
  MzUpload,
  MzDropdown,
  MzDropdownMenu,
  MzDropdownItem,
  MzTransfer,
  MzAlert,
  Notification,
  Loading,
  MzDialog,
  MzForm,
  MzFormItem
};
